"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextField = void 0;
const react_1 = __importStar(require("react"));
const native_1 = __importDefault(require("@emotion/native"));
const react_2 = require("@emotion/react");
const react_native_1 = require("react-native");
const values_js_1 = __importDefault(require("values.js"));
const FieldMessage_1 = require("@procyon/components/FieldMessage");
const Label_1 = require("./Label");
const Skeleton_1 = require("./Skeleton");
const TextField = (props) => {
    var _a;
    const { Input = TextFieldInput, mode = 'text', onClick, onFocus, onBlur, onChange, disabled = false, name, label, color = 'primary', autoFocus, mask, placeholder, multiline, LeftIcon, RightIcon, leftText, rightText, message, style, readonly, size = 'md', labelSize, secret, loading, } = props;
    const [focused, setFocused] = (0, react_1.useState)(false);
    const theme = (0, react_2.useTheme)();
    const applyMask = (val) => {
        if (mask && val) {
            mask.resolve(val);
            return mask.value;
        }
        return val;
    };
    const value = applyMask(props.value);
    const handleClick = (e) => {
        onClick === null || onClick === void 0 ? void 0 : onClick(value, e);
    };
    const handleFocus = (e) => {
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(e.nativeEvent.text, e);
        setFocused(true);
    };
    const handleBlur = (e) => {
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(e.nativeEvent.text, e);
        setFocused(false);
    };
    const handleChange = (e) => {
        const value = e.nativeEvent.text;
        const maskedValue = applyMask(value);
        if (onChange) {
            onChange(maskedValue, e);
        }
    };
    return (react_1.default.createElement(react_native_1.View, { style: [style === null || style === void 0 ? void 0 : style.container], "aria-label": "textfield" },
        react_1.default.createElement(Label_1.Label, { disabled: disabled, size: labelSize }, label),
        react_1.default.createElement(Skeleton_1.Skeleton, { active: loading || false, layout: [{ key: '1', height: 40 }] },
            react_1.default.createElement(TextFieldWrapper, { color: color, disabled: disabled, focused: focused },
                LeftIcon && (react_1.default.createElement(TextFieldIconContainer, { style: [style === null || style === void 0 ? void 0 : style.icon] },
                    react_1.default.createElement(LeftIcon, { style: [textFieldIcon({ icon: true, color, size, theme })] }))),
                leftText && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(react_native_1.Text, { style: [textFieldIcon({ icon: false, color, size, theme })] }, leftText))),
                react_1.default.createElement(react_native_1.Pressable, { onPress: (e) => handleClick(e), style: [
                        {
                            flex: 1,
                            justifyContent: 'center',
                        },
                    ] },
                    react_1.default.createElement(Input, { size: size, style: [style === null || style === void 0 ? void 0 : style.input], id: name, disabled: disabled, secureTextEntry: secret, inputMode: mode, onFocus: handleFocus, onBlur: handleBlur, onChange: handleChange, autoFocus: autoFocus, readOnly: readonly || disabled, value: value !== null && value !== void 0 ? value : '', multiline: multiline, placeholder: placeholder, placeholderTextColor: new values_js_1.default(theme.palette.text.light)
                            .shade(30)
                            .rgbString(), numberOfLines: ((_a = value === null || value === void 0 ? void 0 : value.match(/\n/g)) !== null && _a !== void 0 ? _a : []).length + 1, autoComplete: "off" })),
                RightIcon && (react_1.default.createElement(TextFieldIconContainer, { style: [style === null || style === void 0 ? void 0 : style.icon] },
                    react_1.default.createElement(RightIcon, { style: [textFieldIcon({ icon: true, color, size, theme })] }))),
                rightText && (react_1.default.createElement(TextFieldIconContainer, null,
                    react_1.default.createElement(react_native_1.Text, { style: [textFieldIcon({ icon: false, color, size, theme })] }, rightText))))),
        react_1.default.createElement(FieldMessage_1.FieldMessage, { message: message, color: color, size: size })));
};
exports.TextField = TextField;
const TextFieldWrapper = native_1.default.View(({ theme, color, focused, disabled }) => {
    return Object.assign(Object.assign({ height: 40, display: 'flex', flexDirection: 'row', columnGap: 10, borderRadius: theme.rounded.sm - 1, paddingHorizontal: theme.spacing.lg, borderWidth: 2, borderColor: new values_js_1.default(theme.palette[color].main).tint(80).rgbString(), backgroundColor: new values_js_1.default(theme.palette[color].light).tint(50).rgbString() }, (focused && {
        borderColor: new values_js_1.default(theme.palette[color].main).tint(30).rgbString(),
    })), (disabled && {
        borderColor: new values_js_1.default(theme.palette.base.light).tint(30).rgbString(),
    }));
});
const TextFieldInput = native_1.default.TextInput(({ theme, size, disabled }) => {
    return Object.assign({ color: theme.palette.text.main, fontFamily: theme.fontFamily, paddingVertical: theme.spacing.md, fontSize: theme.fontSize[size] }, (disabled && {
        color: theme.palette.text.disabled,
    }));
});
const TextFieldIconContainer = native_1.default.View(() => {
    return {
        justifyContent: 'center',
    };
});
const textFieldIcon = ({ icon, theme, color, size, }) => ({
    color: theme.palette[color].main,
    fontSize: theme.fontSize[size] + (icon ? 4 : 0),
    fontFamily: theme.fontFamily,
});
